mkierus commented on issue #16702: URL: https://github.com/apache/lucene/issues/16702#issuecomment-5996632278
@kkewwei I validated #16715 against the real-world index, with the same query that this issue was discovered. | build | IndexOrDocValuesQuery | points only | |---|---:|---:| | PR branch with the change reverted | 377 ms | 51 ms | | PR branch (fea7bf3) | 63 ms | 56 ms | | 10.1.0 | 75,089 ms | 96 ms | | 10.1.0 + this change (backported) | 156 ms | 76 ms | End to end through OpenSearch 3.0.0 with the patched 10.1.0 jar, the query goes from ~30 s to ~355 ms, same hit count. A backport to 10.x would help us a lot, since that is what OpenSearch 3.x ships. Thanks for the fix! -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected] --------------------------------------------------------------------- To unsubscribe, e-mail: [email protected] For additional commands, e-mail: [email protected]
